from setuptools import setup, find_packages


setup(
    name="deeptorch",
    version="0.0.1",
    license="MIT",
    author="Benjamin Midtvedt",
    author_email="email@example.com",
    packages=find_packages("deeptorch"),
    package_dir={"": "deeptorch"},
    url="https://github.com/softmatterlab/deeptorch",
    keywords="example project",
    install_requires=[],
)
